@@ -27,7 +27,7 @@ DOCSTRING
 @author: Cyril Desjouy
 """
 
-from .custom_cmap import modified_jet, grayify_cmap, cmap_center_point_adjust, MidpointNormalize
+from .custom_cmap import modified_jet, grayify_cmap, MidPointNorm
 from .multi_pcolor import set_figsize, get_subplot_shape
 
-__version__ = "0.3.2"
+__version__ = "0.4.0"
